@@ -4,7 +4,7 @@
  *
  * Author:
  *   Jukka-Pekka Iivonen (iivonen@iki.fi)
- *   Morten Welinder (terra@diku.dk)
+ *   Morten Welinder (terra@gnome.org)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -66,9 +66,9 @@ find_cells_that_match (Sheet *sheet, GnmValue const *database,
 		cell = sheet_cell_get (sheet, col, row);
 
 		if (cell != NULL)
-			cell_eval (cell);
+			gnm_cell_eval (cell);
 
-		if (cell_is_empty (cell))
+		if (gnm_cell_is_empty (cell))
 			continue;
 
 		add_flag = TRUE;
@@ -83,8 +83,8 @@ find_cells_that_match (Sheet *sheet, GnmValue const *database,
 				GnmCell *tmp = sheet_cell_get (sheet,
 					cond->column, row);
 				if (tmp != NULL)
-					cell_eval (tmp);
-				if (cell_is_empty (tmp) ||
+					gnm_cell_eval (tmp);
+				if (gnm_cell_is_empty (tmp) ||
 				    !cond->fun (tmp->value, cond->x)) {
 					add_flag = FALSE;
 					break;
@@ -132,11 +132,11 @@ database_find_values (Sheet *sheet, GnmValue const *database,
 		GnmCell *cell = current->data;
 		GnmValue *value = cell->value;
 
-		if ((flags & COLLECT_IGNORE_STRINGS) && value->type == VALUE_STRING)
+		if ((flags & COLLECT_IGNORE_STRINGS) && VALUE_IS_STRING (value))
 			continue;
-		if ((flags & COLLECT_IGNORE_BOOLS) && value->type == VALUE_BOOLEAN)
+		if ((flags & COLLECT_IGNORE_BOOLS) && VALUE_IS_BOOLEAN (value))
 			continue;
-		if ((flags & COLLECT_IGNORE_BLANKS) && value->type == VALUE_EMPTY)
+		if ((flags & COLLECT_IGNORE_BLANKS) && VALUE_IS_EMPTY (value))
 			continue;
 		if (floats)
 			res1[count++] = value_get_as_float (value);
@@ -152,7 +152,7 @@ database_find_values (Sheet *sheet, GnmValue const *database,
 /***************************************************************************/
 
 static GnmValue *
-database_float_range_function (FunctionEvalInfo *ei,
+database_float_range_function (GnmFuncEvalInfo *ei,
 			       GnmValue const *database,
 			       GnmValue const *field,
 			       GnmValue const *criteria,
@@ -174,6 +174,10 @@ database_float_range_function (FunctionEvalInfo *ei,
 	if (fieldno < 0)
 		return value_new_error_NUM (ei->pos);
 
+	/* I don't like this -- minimal fix for now.  509427.  */
+	if (criteria->type != VALUE_CELLRANGE)
+		return value_new_error_NUM (ei->pos);
+
 	criterias = parse_database_criteria (ei->pos, database, criteria);
 	if (criterias == NULL)
 		return value_new_error_NUM (ei->pos);
@@ -211,7 +215,7 @@ database_float_range_function (FunctionEvalInfo *ei,
 typedef int (*value_range_function_t) (GnmValue **, int, GnmValue **);
 
 static GnmValue *
-database_value_range_function (FunctionEvalInfo *ei,
+database_value_range_function (GnmFuncEvalInfo *ei,
 			       GnmValue const *database,
 			       GnmValue const *field,
 			       GnmValue const *criteria,
@@ -232,6 +236,10 @@ database_value_range_function (FunctionEvalInfo *ei,
 	if (fieldno < 0)
 		return value_new_error_NUM (ei->pos);
 
+	/* I don't like this -- minimal fix for now.  509427.  */
+	if (criteria->type != VALUE_CELLRANGE)
+		return value_new_error_NUM (ei->pos);
+
 	criterias = parse_database_criteria (ei->pos, database, criteria);
 	if (criterias == NULL)
 		return value_new_error_NUM (ei->pos);
@@ -325,13 +333,13 @@ static GnmFuncHelp const help_daverage[] = {
 };
 
 static GnmValue *
-gnumeric_daverage (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_daverage (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
 					      argv[1],
 					      argv[2],
-					      range_average,
+					      gnm_range_average,
 					      COLLECT_IGNORE_STRINGS |
 					      COLLECT_IGNORE_BOOLS |
 					      COLLECT_IGNORE_BLANKS,
@@ -401,13 +409,13 @@ static GnmFuncHelp const help_dcount[] = {
 };
 
 static GnmValue *
-gnumeric_dcount (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_dcount (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
 					      argv[1],
 					      argv[2],
-					      range_count,
+					      gnm_range_count,
 					      COLLECT_IGNORE_STRINGS |
 					      COLLECT_IGNORE_BOOLS |
 					      COLLECT_IGNORE_BLANKS,
@@ -477,13 +485,13 @@ static GnmFuncHelp const help_dcounta[] = {
 };
 
 static GnmValue *
-gnumeric_dcounta (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_dcounta (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
 					      argv[1],
 					      argv[2],
-					      range_count,
+					      gnm_range_count,
 					      COLLECT_IGNORE_BLANKS,
 					      GNM_ERROR_UNKNOWN,
 					      GNM_ERROR_NUM);
@@ -565,7 +573,7 @@ range_first (GnmValue **xs, int n, GnmValue **res)
 }
 
 static GnmValue *
-gnumeric_dget (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_dget (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return database_value_range_function (ei,
 					      argv[0],
@@ -639,13 +647,13 @@ static GnmFuncHelp const help_dmax[] = {
 /***************************************************************************/
 
 static GnmValue *
-gnumeric_dmax (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_dmax (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
 					      argv[1],
 					      argv[2],
-					      range_max,
+					      gnm_range_max,
 					      COLLECT_IGNORE_STRINGS |
 					      COLLECT_IGNORE_BOOLS |
 					      COLLECT_IGNORE_BLANKS,
@@ -714,13 +722,13 @@ static GnmFuncHelp const help_dmin[] = {
 };
 
 static GnmValue *
-gnumeric_dmin (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_dmin (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
 					      argv[1],
 					      argv[2],
-					      range_min,
+					      gnm_range_min,
 					      COLLECT_IGNORE_STRINGS |
 					      COLLECT_IGNORE_BOOLS |
 					      COLLECT_IGNORE_BLANKS,
@@ -788,14 +796,14 @@ static GnmFuncHelp const help_dproduct[] = {
 };
 
 static GnmValue *
-gnumeric_dproduct (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_dproduct (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	/* FIXME: check what happens for zero count.  */
 	return database_float_range_function (ei,
 					      argv[0],
 					      argv[1],
 					      argv[2],
-					      range_product,
+					      gnm_range_product,
 					      COLLECT_IGNORE_STRINGS |
 					      COLLECT_IGNORE_BOOLS |
 					      COLLECT_IGNORE_BLANKS,
@@ -865,13 +873,13 @@ static GnmFuncHelp const help_dstdev[] = {
 };
 
 static GnmValue *
-gnumeric_dstdev (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_dstdev (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
 					      argv[1],
 					      argv[2],
-					      range_stddev_est,
+					      gnm_range_stddev_est,
 					      COLLECT_IGNORE_STRINGS |
 					      COLLECT_IGNORE_BOOLS |
 					      COLLECT_IGNORE_BLANKS,
@@ -941,13 +949,13 @@ static GnmFuncHelp const help_dstdevp[] = {
 };
 
 static GnmValue *
-gnumeric_dstdevp (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_dstdevp (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
 					      argv[1],
 					      argv[2],
-					      range_stddev_pop,
+					      gnm_range_stddev_pop,
 					      COLLECT_IGNORE_STRINGS |
 					      COLLECT_IGNORE_BOOLS |
 					      COLLECT_IGNORE_BLANKS,
@@ -1016,14 +1024,14 @@ static GnmFuncHelp const help_dsum[] = {
 };
 
 static GnmValue *
-gnumeric_dsum (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_dsum (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	/* FIXME: check what happens for zero count.  */
 	return database_float_range_function (ei,
 					      argv[0],
 					      argv[1],
 					      argv[2],
-					      range_sum,
+					      gnm_range_sum,
 					      COLLECT_IGNORE_STRINGS |
 					      COLLECT_IGNORE_BOOLS |
 					      COLLECT_IGNORE_BLANKS,
@@ -1093,13 +1101,13 @@ static GnmFuncHelp const help_dvar[] = {
 };
 
 static GnmValue *
-gnumeric_dvar (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_dvar (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
 					      argv[1],
 					      argv[2],
-					      range_var_est,
+					      gnm_range_var_est,
 					      COLLECT_IGNORE_STRINGS |
 					      COLLECT_IGNORE_BOOLS |
 					      COLLECT_IGNORE_BLANKS,
@@ -1169,13 +1177,13 @@ static GnmFuncHelp const help_dvarp[] = {
 };
 
 static GnmValue *
-gnumeric_dvarp (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_dvarp (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
 					      argv[1],
 					      argv[2],
-					      range_var_pop,
+					      gnm_range_var_pop,
 					      COLLECT_IGNORE_STRINGS |
 					      COLLECT_IGNORE_BOOLS |
 					      COLLECT_IGNORE_BLANKS,
@@ -1207,7 +1215,7 @@ static GnmFuncHelp const help_getpivotdata[] = {
 };
 
 static GnmValue *
-gnumeric_getpivotdata (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_getpivotdata (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	int  col, row;
 	GnmCell *cell;
@@ -1222,9 +1230,9 @@ gnumeric_getpivotdata (FunctionEvalInfo *ei, GnmValue const * const *argv)
 	/* FIXME: Lots of stuff missing */
 
 	if (cell != NULL)
-		cell_eval (cell);
+		gnm_cell_eval (cell);
 
-	if (cell_is_empty (cell) ||
+	if (gnm_cell_is_empty (cell) ||
 	    !VALUE_IS_NUMBER (cell->value))
 		return value_new_error_REF (ei->pos);
 
