@@ -31,7 +31,7 @@
  *
  *
  * The LaTeX2e function is named:
- * 		latex_file_save()
+ *		latex_file_save()
  *
  */
 
@@ -139,8 +139,8 @@ static latex_border_connectors_t const conn_styles[LATEX_MAX_BORDER]
  *
  * @return:
  * If @p is in form of \L{foo}, return the char pointer pointing to '}' of \L{foo}
- * else return @p untouched; 
- * 
+ * else return @p untouched;
+ *
  * Check if @p is in form of \L{foo}.
  * If it is, the exact "foo" will be put into @output, without any esacaping.
  *
@@ -210,9 +210,9 @@ latex_fputs_utf (char const *p, GsfOutput *output)
 		case '>': case '<':
 			gsf_output_printf (output, "$%c$", *p);
 			break;
-			
+
 		default:
-			gsf_output_write (output, 
+			gsf_output_write (output,
 					  (g_utf8_next_char (p)) - p, p);
 			break;
 		}
@@ -227,7 +227,7 @@ latex_fputs_utf (char const *p, GsfOutput *output)
  *
  * This escapes any special LaTeX characters from the LaTeX engine,
  * except the ones enclosed in "\L{" and "}".
- * 
+ *
  * We assume that htis will be set in Mathematics mode.
  */
 static void
@@ -253,7 +253,7 @@ latex_math_fputs_utf (char const *p, GsfOutput *output)
 				    p = rlt;
 				break;
 			default:
-				gsf_output_write (output, 
+				gsf_output_write (output,
 						  (g_utf8_next_char (p)) - p, p);
 				break;
 		}
@@ -281,7 +281,7 @@ latex_convert_latin_to_utf (char const *text)
 	if (g_utf8_strchr (text,-1, 0x2212) == NULL) {
 		encoded_text = g_convert_with_fallback
 			(text, strlen (text),
-			 "ISO-8859-1", "UTF-8", (gchar *)"?", 
+			 "ISO-8859-1", "UTF-8", (gchar *)"?",
 			 &bytes_read, &bytes_written, NULL);
 	} else {
 		gunichar* ucs_string = NULL;
@@ -299,7 +299,7 @@ latex_convert_latin_to_utf (char const *text)
 		g_free (ucs_string);
 		encoded_text = g_convert_with_fallback
 			(new_text, strlen (new_text),
-			 "ISO-8859-1", "UTF-8", (gchar *)"?", 
+			 "ISO-8859-1", "UTF-8", (gchar *)"?",
 			 &bytes_read, &bytes_written, NULL);
 		g_free (new_text);
 	}
@@ -328,7 +328,7 @@ latex_fputs_latin (char const *text, GsfOutput *output)
 
 	for (p = encoded_text; *p; p++) {
 		switch (*p) {
-			
+
 			/* These are the classic TeX symbols $ & % # _ { } (see Lamport, p.15) */
 		case '$': case '&': case '%': case '#':
 		case '_': case '{': case '}':
@@ -349,7 +349,7 @@ latex_fputs_latin (char const *text, GsfOutput *output)
 		case '>': case '<': case '':
 			gsf_output_printf (output, "$%c$", *p);
 			break;
-			
+
 		default:
 			gsf_output_write (output, 1, p);
 			break;
@@ -364,9 +364,9 @@ latex_fputs_latin (char const *text, GsfOutput *output)
  * @p :     a pointer to a char, start of the string to be processed.
  * @output: output stream where the processed characters are written.
  *
- * This escapes any special LaTeX characters from the LaTeX engine, 
+ * This escapes any special LaTeX characters from the LaTeX engine,
  * except the ones enclosed in "\L{" and "}".
- * 
+ *
  * We assume that htis will be set in Mathematics mode.
  */
 static void
@@ -503,7 +503,7 @@ latex2e_write_file_header(GsfOutput *output)
 "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%\n"
 "\n"
 "	\\documentclass[12pt%\n"
-"	                  %,landscape%\n"
+"			  %,landscape%\n"
 "                    ]{report}\n"
 		);
 
@@ -556,7 +556,7 @@ latex2e_write_file_header(GsfOutput *output)
 "%%                                                                  %%\n"
 "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%\n"
 "\n"
-"\\providecommand{\\gnumericmathit}[1]{#1} \n" 
+"\\providecommand{\\gnumericmathit}[1]{#1} \n"
 "%%  Uncomment the next line if you would like your numbers to be in %%\n"
 "%%  italics if they are italizised in the gnumeric table.           %%\n"
 "%\\renewcommand{\\gnumericmathit}[1]{\\mathit{#1}}\n"
@@ -601,7 +601,7 @@ latex2e_write_table_header(GsfOutput *output, int num_cols)
 	int col;
 
 
-	gsf_output_puts (output, 
+	gsf_output_puts (output,
 "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%\n"
 "%%  The longtable options. (Caption, headers... see Goosens, p.124) %%\n"
 "%\t\\caption{The Table Caption.}             \\\\	%\n"
@@ -669,13 +669,15 @@ latex2e_find_vline (int col, int row, Sheet *sheet, GnmStyleElement which_border
 		return border->line_type;
 
 	if (which_border == MSTYLE_BORDER_LEFT) {
-		if (col < 1)
+		if (col <= 0)
 			return GNM_STYLE_BORDER_NONE;
 		style = sheet_style_get (sheet, col - 1, row);
 		border = gnm_style_get_border (style, MSTYLE_BORDER_RIGHT);
 		return ((gnm_style_border_is_blank (border)) ? GNM_STYLE_BORDER_NONE :
 			border->line_type);
 	} else {
+		if ((col+1) >= colrow_max (TRUE))
+		    return GNM_STYLE_BORDER_NONE;
 		style = sheet_style_get (sheet, col + 1, row);
 		border = gnm_style_get_border (style, MSTYLE_BORDER_LEFT);
 		return ((gnm_style_border_is_blank (border)) ? GNM_STYLE_BORDER_NONE :
@@ -928,7 +930,7 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
 
 	/* Send the alignment of the cell through a routine to deal with
 	 * HALIGN_GENERAL and then deal with the three cases. */
-	switch ( style_default_halign(style, cell) ) {
+	switch (gnm_style_default_halign (style, cell)) {
 	case HALIGN_RIGHT:
 		gsf_output_printf (output, "\\gnumericPB{\\raggedleft}");
 		break;
@@ -952,7 +954,7 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
 	/* if we don't wrap put it into an mbox, adjusted to width 0 to avoid moving */
 	/* it to the second line of the parbox */
 	if (!wrap)
-		switch ( style_default_halign(style, cell) ) {
+		switch (gnm_style_default_halign (style, cell)) {
 		case HALIGN_RIGHT:
 			gsf_output_printf (output, "\\gnumbox[r]{");
 			break;
@@ -992,7 +994,7 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
 
 		/* Establish the font's style for the styles that can be addressed by LaTeX.
 		 * More complicated efforts (like changing fonts) are left to the user.
-      		 */
+		 */
 
 		if (hidden)
 			gsf_output_printf (output, "\\phantom{");
@@ -1014,7 +1016,7 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
 		    cell_format_family == GO_FORMAT_FRACTION ||
 		    cell_format_family == GO_FORMAT_SCIENTIFIC){
 			gsf_output_printf (output, "$");
-		        if (gnm_style_get_font_italic(style))
+			if (gnm_style_get_font_italic(style))
 			    gsf_output_printf (output, "\\gnumericmathit{");
 
 			/* Print the cell contents. */
@@ -1022,7 +1024,7 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
 			latex_math_fputs (rendered_string, output);
 			g_free (rendered_string);
 
-		        if (gnm_style_get_font_italic(style))
+			if (gnm_style_get_font_italic(style))
 			    gsf_output_printf (output, "}");
 			gsf_output_printf (output, "$");
 		} else {
@@ -1084,7 +1086,7 @@ latex2e_find_hhlines (GnmStyleBorderType *clines, int length, int col, int row,
 {
 	GnmStyle const	*style;
 	GnmBorder const	*border;
- 	GnmRange const	*merge_range;
+	GnmRange const	*merge_range;
 	GnmCellPos pos;
 
 	style = sheet_style_get (sheet, col, row);
@@ -1180,7 +1182,7 @@ latex_file_save (GOFileSaver const *fs, IOContext *io_context,
 	GnmCell *cell;
 	Sheet *current_sheet;
 	GnmRange total_range;
- 	GnmRange const *merge_range;
+	GnmRange const *merge_range;
 	int row, col, num_cols, length;
 	int num_merged_cols, num_merged_rows;
 	GnmStyleBorderType *clines, *this_clines;
@@ -1294,11 +1296,11 @@ latex_file_save (GOFileSaver const *fs, IOContext *io_context,
 		g_free (clines);
 
 		for (col = total_range.start.col; col <= total_range.end.col; col++) {
-		        GnmCellPos pos;
+			GnmCellPos pos;
 
 			pos.col = col;
 			pos.row = row;
-			
+
 			/* Get the cell. */
 			cell = sheet_cell_get (current_sheet, col, row);
 
@@ -1311,13 +1313,13 @@ latex_file_save (GOFileSaver const *fs, IOContext *io_context,
 			/* Check a merge. */
 			merge_range = gnm_sheet_merge_is_corner (current_sheet, &pos);
 			if (merge_range == NULL) {
-			        if (gnm_cell_is_empty(cell))
-				        latex2e_write_blank_multicolumn_cell(output, col, row,
+				if (gnm_cell_is_empty(cell))
+					latex2e_write_blank_multicolumn_cell(output, col, row,
 									     1, 1,
 							       col - total_range.start.col,
 							       next_vert, current_sheet);
 				else
-				        latex2e_write_multicolumn_cell(output, cell, col,
+					latex2e_write_multicolumn_cell(output, cell, col,
 								       1, 1,
 							       col - total_range.start.col,
 							       next_vert, current_sheet);
@@ -1329,7 +1331,7 @@ latex_file_save (GOFileSaver const *fs, IOContext *io_context,
 			num_merged_rows = merge_range->end.row - merge_range->start.row + 1;
 
 			if (gnm_cell_is_empty(cell))
-				latex2e_write_blank_multicolumn_cell(output, col, row, 
+				latex2e_write_blank_multicolumn_cell(output, col, row,
 								     num_merged_cols,
 								     num_merged_rows,
 								     col - total_range.start.col,
