@@ -1,5 +1,5 @@
 /* vim: set sw=8:
- * $Id: boot.c,v 1.12 2005/08/08 09:38:37 jdassen Exp $
+ * $Id: boot.c 14619 2006-03-19 17:12:15Z jody $
  */
 
 /*
@@ -53,5 +53,5 @@ void
 psiconv_file_open (GOFileOpener const *fo, IOContext *io_context,
                   WorkbookView *wb_view, GsfInput *input)
 {
-	psiconv_read (io_context, wb_view_workbook(wb_view), input);
+	psiconv_read (io_context, wb_view_get_workbook(wb_view), input);
 }
