@@ -26,6 +26,7 @@
 #include "dialog-stf.h"
 #include <gnm-format.h>
 #include <workbook.h>
+#include <workbook-control.h>
 #include <gui-util.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
@@ -369,7 +370,7 @@ cb_col_event (GtkWidget *widget, GdkEvent *event, gpointer _col)
 			/*
 			 * We use overlapping buttons and that does not actually work...
 			 *
-			 * In a square area the height of the hbox, click the the
+			 * In a square area the height of the hbox, click the
 			 * checkbox.
 			 */
 			int xmax = GTK_BIN (widget)->child->allocation.height;
@@ -535,10 +536,11 @@ format_page_update_preview (StfDialogData *pagedata)
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(check),
 						      pagedata->
 						      format.col_import_array[i]);
-			gtk_tooltips_set_tip (renderdata->tooltips, check,
-					      _("If this checkbox is selected, the "
-						"column will be imported into "
-						"Gnumeric."), msg);
+			go_widget_set_tooltip_text
+				(check,
+				 _("If this checkbox is selected, the "
+				   "column will be imported into "
+				   "Gnumeric."));
 			g_object_set_data (G_OBJECT (check), "pagedata", pagedata);
 			gtk_box_pack_start (GTK_BOX(box), check, FALSE, FALSE, 0);
 			gtk_box_pack_start (GTK_BOX(box), label, TRUE, TRUE, 0);
