@@ -45,6 +45,29 @@
 #include <string.h>
 #include <unistd.h>
 
+static gboolean
+debug_clipboard (void)
+{
+	static guint flags;
+	static gboolean inited = FALSE;
+
+	if (!inited) {
+		/* not static */
+		const GDebugKey keys[] = {
+			{ (char*)"clipboard", 1 },
+		};
+
+		const char *val = g_getenv ("GNM_DEBUG");
+		flags = val
+			? g_parse_debug_string (val, keys, G_N_ELEMENTS (keys))
+			: 0;
+
+		inited = TRUE;
+	}
+
+	return (flags & 1) != 0;
+}
+
 typedef struct {
 	WBCGtk *wbcg;
 	GnmPasteTarget        *paste_target;
@@ -475,7 +498,9 @@ table_cellregion_write (GOCmdContext *ctx, GnmCellRegion *cr,
 	r.end.col = cr->cols - 1;
 	r.end.row = cr->rows - 1;
 
-	paste_target_init (&pt, sheet, &r, PASTE_ALL_TYPES);
+	paste_target_init (&pt, sheet, &r, 
+			   PASTE_AS_VALUES | PASTE_FORMATS | 
+			   PASTE_COMMENTS | PASTE_OBJECTS);
 	if (clipboard_paste_region (cr, &pt, ctx) == FALSE) {
 		go_file_saver_save (saver, ioc, wb_view, output);
 		if (!gnumeric_io_error_occurred (ioc)) {
@@ -615,6 +640,9 @@ x_clipboard_get_cb (GtkClipboard *gclipboard, GtkSelectionData *selection_data,
 	GOCmdContext *ctx = cmd_context_stderr_new ();
 	gchar *target_name = gdk_atom_name (selection_data->target);
 
+	if (debug_clipboard ())
+		g_message ("clipboard target=%s", target_name);
+
 	/*
 	 * There are 4 cases. What variables are valid depends on case:
 	 * source is
@@ -639,10 +667,14 @@ x_clipboard_get_cb (GtkClipboard *gclipboard, GtkSelectionData *selection_data,
 	if (selection_data->target == gdk_atom_intern (GNUMERIC_ATOM_NAME, FALSE)) {
 		GsfOutputMemory *output  = gnm_cellregion_to_xml (clipboard);
 		if (output) {
+			gsf_off_t size = gsf_output_size (GSF_OUTPUT (output));
+			if (debug_clipboard ())
+				g_message ("clipboard .gnumeric of %d bytes",
+					   (int)size);
 			gtk_selection_data_set
 				(selection_data, selection_data->target, 8,
 				 gsf_output_memory_get_bytes (output),
-				 gsf_output_size (GSF_OUTPUT (output)));
+				 size);
 			g_object_unref (output);
 			to_gnumeric = TRUE;
 		}
@@ -652,6 +684,9 @@ x_clipboard_get_cb (GtkClipboard *gclipboard, GtkSelectionData *selection_data,
 		guchar *buffer = table_cellregion_write (ctx, clipboard,
 							 saver_id,
 							 &buffer_size);
+		if (debug_clipboard ())
+			g_message ("clipboard html of %d bytes",
+				    buffer_size);
 		gtk_selection_data_set (selection_data,
 					selection_data->target, 8,
 					(guchar *) buffer, buffer_size);
@@ -660,6 +695,9 @@ x_clipboard_get_cb (GtkClipboard *gclipboard, GtkSelectionData *selection_data,
 		int buffer_size;
 		guchar *buffer = graph_write (clipboard, target_name,
 					      &buffer_size);
+		if (debug_clipboard ())
+			g_message ("clipboard graph of %d bytes",
+				   buffer_size);
 		gtk_selection_data_set (selection_data,
 					selection_data->target, 8,
 					(guchar *) buffer, buffer_size);
@@ -668,6 +706,9 @@ x_clipboard_get_cb (GtkClipboard *gclipboard, GtkSelectionData *selection_data,
 		int buffer_size;
 		guchar *buffer = image_write (clipboard, target_name,
 					      &buffer_size);
+		if (debug_clipboard ())
+			g_message ("clipboard image of %d bytes",
+				    buffer_size);
 		gtk_selection_data_set (selection_data,
 					selection_data->target, 8,
 					(guchar *) buffer, buffer_size);
@@ -681,22 +722,31 @@ x_clipboard_get_cb (GtkClipboard *gclipboard, GtkSelectionData *selection_data,
 		GString *res = cellregion_to_string (clipboard,
 			TRUE, workbook_date_conv (wb));
 		if (res != NULL) {
+			if (debug_clipboard ())
+				g_message ("clipboard text of %d bytes",
+					   (int)res->len);
 			gtk_selection_data_set_text (selection_data,
 				res->str, res->len);
 			g_string_free (res, TRUE);
 		} else {
+			if (debug_clipboard ())
+				g_message ("clipboard empty text");
 			gtk_selection_data_set_text (selection_data, "", 0);
 		}
 	}
 
 	/*
-	 * If this was a CUT operation we need to clear the content that was pasted
-	 * into another application and release the stuff on the clipboard
+	 * If this was a CUT operation we need to clear the content that
+	 * was pasted into another application and release the stuff on
+	 * the clipboard
 	 */
 	if (content_needs_free) {
 
 		/* If the other app was a gnumeric, emulate a cut */
 		if (to_gnumeric) {
+			/* FIXME: This needs undo.
+			 * Use a variant of cmd_selection_clear that would use
+			 * the src range rather than the current selection */
 			sheet_clear_region (sheet,
 				a->start.col, a->start.row,
 				a->end.col,   a->end.row,
@@ -777,6 +827,51 @@ target_list_to_entries (GtkTargetList *target_list, int *n_entries)
 	return entries;
 }
 
+/* Restrict the	set of formats offered to clipboard manager. */
+/* We include bmp in the whitelist because that's the only image format 
+ * we share with OOo over clipboard (!) */
+static void
+set_clipman_targets (GdkDisplay *disp, GtkTargetEntry *targets, int n_targets)
+{
+	static GtkTargetEntry clipman_whitelist[] = {
+		{ (char *) GNUMERIC_ATOM_NAME, 0, GNUMERIC_ATOM_INFO },
+		{ (char *)"text/html", 0, 0 },
+		{ (char *)"UTF8_STRING", 0, 0 },
+		{ (char *)"application/x-goffice-graph", 0, 0 },
+		{ (char *)"image/svg+xml", 0, 0 },
+		{ (char *)"image/x-wmf", 0, 0 },
+		{ (char *)"image/x-emf", 0, 0 },
+		{ (char *)"image/png", 0, 0 },
+		{ (char *)"image/jpeg", 0, 0 },
+		{ (char *)"image/bmp", 0, 0 },
+	};
+	int n_whitelist = G_N_ELEMENTS (clipman_whitelist);
+	int n_allowed;
+	GtkTargetList *tl = gtk_target_list_new(NULL, 0);
+	GtkTargetEntry *t, *wt, *t_allowed;
+
+	for (t = targets; t - targets < n_targets; t++) {
+		for (wt = clipman_whitelist; 
+		     wt - clipman_whitelist < n_whitelist; wt++) {
+			if (strcmp(t->target, wt->target) == 0) {
+				gtk_target_list_add 
+					(tl, gdk_atom_intern (t->target, FALSE), 
+					 t->flags, t->info);
+				break;
+			}
+		}
+	}
+	
+	t_allowed = gtk_target_table_new_from_list (tl, &n_allowed);
+
+	gtk_clipboard_set_can_store (
+			gtk_clipboard_get_for_display (
+				disp, GDK_SELECTION_CLIPBOARD),
+				t_allowed, n_allowed);
+	gtk_target_table_free (t_allowed, n_allowed);
+	t_allowed = NULL;
+}
+
 gboolean
 x_claim_clipboard (WBCGtk *wbcg)
 {
@@ -836,10 +931,7 @@ x_claim_clipboard (WBCGtk *wbcg)
 		(GtkClipboardClearFunc) x_clipboard_clear_cb,
 		gnm_app_get_app ());
 	if (ret) {
-		gtk_clipboard_set_can_store (
-			gtk_clipboard_get_for_display (
-				display, GDK_SELECTION_CLIPBOARD),
-				targets, n_targets);
+		set_clipman_targets (display, targets, n_targets);
 		ret = gtk_clipboard_set_with_owner (
 			gtk_clipboard_get_for_display (display,
 						       GDK_SELECTION_PRIMARY),
