@@ -49,7 +49,7 @@ struct _ItemEdit {
 	FooCanvasItem item;
 
 	SheetControlGUI *scg;
-	GtkEntry   	*entry;		/* Utility pointer to the workbook entry */
+	GtkEntry	*entry;		/* Utility pointer to the workbook entry */
 
 	PangoLayout	*layout;
 
@@ -61,11 +61,6 @@ struct _ItemEdit {
 	GnmFont   *gfont;
 	GnmStyle  *style;
 	GdkGC     *fill_gc;	/* Default background fill gc */
-
-	/* When editing, if the cursor is inside a cell name, or a cell range,
-	 * we highlight this on the spreadsheet. */
-	FooCanvasItem *feedback_cursor [SCG_NUM_PANES];
-	gboolean       feedback_disabled;
 };
 
 typedef FooCanvasItemClass ItemEditClass;
@@ -76,56 +71,6 @@ enum {
 	ARG_SHEET_CONTROL_GUI	/* The SheetControlGUI * argument */
 };
 
-static void
-ie_destroy_feedback_range (ItemEdit *ie)
-{
-	int i = G_N_ELEMENTS (ie->feedback_cursor);
-
-	while (i-- > 0)
-		if (ie->feedback_cursor[i] != NULL) {
-			gtk_object_destroy (GTK_OBJECT (ie->feedback_cursor[i]));
-			ie->feedback_cursor[i] = NULL;
-		}
-}
-
-/* WARNING : DO NOT CALL THIS FROM FROM UPDATE.  It may create another
- *           canvas-item which would in turn call update and confuse the
- *           canvas.
- */
-static void
-ie_scan_for_range (ItemEdit *ie)
-{
-	GnmRange  range;
-	Sheet *sheet = scg_sheet (ie->scg);
-	Sheet *parse_sheet;
-	GnmParsePos pp;
-	GnmExprEntry *gee = GNM_EXPR_ENTRY (
-		gtk_widget_get_parent (GTK_WIDGET (ie->entry)));
-
-	gnm_expr_entry_set_parsepos (gee,
-		parse_pos_init_editpos (&pp, scg_view (ie->scg)));
-	if (!ie->feedback_disabled) {
-		gnm_expr_expr_find_range (gee);
-		if (gnm_expr_entry_get_rangesel (gee, &range, &parse_sheet) &&
-		    parse_sheet == sheet) {
-			SCG_FOREACH_PANE (ie->scg, pane, {
-				if (ie->feedback_cursor[i] == NULL)
-					ie->feedback_cursor[i] = foo_canvas_item_new (
-						FOO_CANVAS_GROUP (FOO_CANVAS (pane)->root),
-					item_cursor_get_type (),
-					"SheetControlGUI",	ie->scg,
-					"style",		ITEM_CURSOR_BLOCK,
-					"color",		"blue",
-					NULL);
-				item_cursor_bound_set (ITEM_CURSOR (ie->feedback_cursor[i]), &range);
-			});
-			return;
-		}
-	}
-
-	ie_destroy_feedback_range (ie);
-}
-
 static void
 get_top_left (ItemEdit const *ie, int *top, int *left)
 {
@@ -149,13 +94,13 @@ item_edit_draw (FooCanvasItem *item, GdkDrawable *drawable,
 		GdkEventExpose *expose)
 {
 	ItemEdit  const *ie	= ITEM_EDIT (item);
-	GdkGC *black_gc 	= GTK_WIDGET (item->canvas)->style->black_gc;
+	GdkGC *black_gc		= GTK_WIDGET (item->canvas)->style->black_gc;
 	int top, left;
 
 	if (ie->style == NULL)
 		return;
 
-       	/* Draw the background (recall that gdk_draw_rectangle excludes far coords) */
+	/* Draw the background (recall that gdk_draw_rectangle excludes far coords) */
 	gdk_draw_rectangle (drawable, ie->fill_gc, TRUE,
 		(int)item->x1,			(int)item->y1,
 		(int)(item->x2 - item->x1),	(int)(item->y2 - item->y1));
@@ -244,7 +189,7 @@ ie_layout (FooCanvasItem *item)
 	GtkWidget const  *canvas = GTK_WIDGET (item->canvas);
 	GnmPane	 const  *pane = GNM_PANE (item->canvas);
 	ColRowInfo const *ci;
-	Sheet const 	 *sheet  = scg_sheet (ie->scg);
+	Sheet const	 *sheet  = scg_sheet (ie->scg);
 	GnmFont  const   *gfont = ie->gfont;
 	GnmRange const   *merged;
 	int col, tmp, width, height, col_size;
@@ -319,8 +264,8 @@ ie_layout (FooCanvasItem *item)
 	col_size -= GNM_COL_MARGIN + GNM_COL_MARGIN + 1;
 
 	/* far corner based on the span size
-	 * 	- margin on each end
-	 * 	- the bound excludes the far point => +1 */
+	 *	- margin on each end
+	 *	- the bound excludes the far point => +1 */
 	if (sheet->text_is_rtl) {
 		while (col_size < width && col >= pane->first.col) {
 			ci = sheet_col_get_info (sheet, col--);
@@ -438,7 +383,7 @@ item_edit_cursor_blink_start (ItemEdit *ie)
 	g_object_get (gtk_widget_get_settings (
 		GTK_WIDGET (ie->item.canvas)),
 		"gtk-cursor-blink-time",	&blink_time,
-		"gtk-cursor-blink", 		&blink,
+		"gtk-cursor-blink",		&blink,
 		NULL);
 	if (blink)
 		ie->blink_timer = g_timeout_add ( blink_time,
@@ -449,7 +394,6 @@ static void
 item_edit_init (ItemEdit *ie)
 {
 	FooCanvasItem *item = FOO_CANVAS_ITEM (ie);
-	int i;
 
 	/* Apply an arbitrary size/pos for now.  Init when we get the scg */
 	item->x1 = 0;
@@ -463,27 +407,7 @@ item_edit_init (ItemEdit *ie)
 	ie->gfont = NULL;
 	ie->style      = NULL;
 	ie->cursor_visible = TRUE;
-	ie->feedback_disabled = FALSE;
 	ie->fill_gc = NULL;
-	for (i = G_N_ELEMENTS (ie->feedback_cursor); i-- > 0 ; )
-		ie->feedback_cursor[i] = NULL;
-}
-
-/*
- * Invoked when the GtkEntry has changed
- *
- * We use this to sync up the GtkEntry with our display on the screen.
- */
-static void
-entry_changed (FooCanvasItem *item)
-{
-	ItemEdit *ie = ITEM_EDIT (item);
-	char const *text = gtk_entry_get_text (ie->entry);
-
-	if (gnm_expr_char_start_p (text))
-		ie_scan_for_range (ie);
-
-	foo_canvas_item_request_update (item);
 }
 
 static void
@@ -492,14 +416,17 @@ item_edit_dispose (GObject *gobject)
 	ItemEdit *ie = ITEM_EDIT (gobject);
 
 	item_edit_cursor_blink_stop (ie);
-	ie_destroy_feedback_range (ie);
+
+	/* to destroy the feedback ranges */
+	gnm_expr_entry_disable_highlight (
+		wbcg_get_entry_logical (scg_wbcg (ie->scg)));
 #if 0
 	/* Why?  */
 	scg_set_display_cursor (ie->scg);
 #endif
 
 	if (ie->gfont != NULL) {
-		style_font_unref (ie->gfont);
+		gnm_font_unref (ie->gfont);
 		ie->gfont = NULL;
 	}
 	if (ie->style != NULL) {
@@ -511,20 +438,19 @@ item_edit_dispose (GObject *gobject)
 }
 
 static int
-entry_key_press (FooCanvasItem *item)
+cb_entry_key_press (FooCanvasItem *item)
 {
-	entry_changed (item);
+	foo_canvas_item_request_update (item);
 	return TRUE;
 }
 
 static int
-entry_cursor_event (FooCanvasItem *item)
+cb_entry_cursor_event (FooCanvasItem *item)
 {
 	/* ensure we draw a cursor when moving quickly no matter what the
 	 * current state is */
 	ITEM_EDIT (item)->cursor_visible = TRUE;
-
-	entry_changed (item);
+	foo_canvas_item_request_update (item);
 	return TRUE;
 }
 
@@ -536,7 +462,6 @@ item_edit_set_property (GObject *gobject, guint param_id,
 	ItemEdit        *ie = ITEM_EDIT (gobject);
 	GnmPane		*pane = GNM_PANE (item->canvas);
 	SheetView const	*sv;
-	GtkEntry        *entry;
 
 	/* We can only set the sheet-control-gui once */
 	g_return_if_fail (param_id == ARG_SHEET_CONTROL_GUI);
@@ -546,21 +471,19 @@ item_edit_set_property (GObject *gobject, guint param_id,
 
 	sv = scg_view (ie->scg);
 	ie->pos = sv->edit_pos;
-	ie->entry = entry = wbcg_get_entry (scg_wbcg (ie->scg));
+	ie->entry = wbcg_get_entry (scg_wbcg (ie->scg));
 	g_signal_connect_object (G_OBJECT (scg_wbcg (ie->scg)),
 		"markup-changed",
 		G_CALLBACK (foo_canvas_item_request_update), G_OBJECT (ie), G_CONNECT_SWAPPED);
-	g_signal_connect_object (G_OBJECT (gtk_widget_get_parent (GTK_WIDGET (entry))),
+	g_signal_connect_object (G_OBJECT (gtk_widget_get_parent (GTK_WIDGET (ie->entry))),
 		"changed",
-		G_CALLBACK (entry_changed), G_OBJECT (ie), G_CONNECT_SWAPPED);
-	g_signal_connect_object (G_OBJECT (entry),
+		G_CALLBACK (foo_canvas_item_request_update), G_OBJECT (ie), G_CONNECT_SWAPPED);
+	g_signal_connect_object (G_OBJECT (ie->entry),
 		"key-press-event",
-		G_CALLBACK (entry_key_press), G_OBJECT (ie), G_CONNECT_AFTER|G_CONNECT_SWAPPED);
-	g_signal_connect_object (G_OBJECT (entry),
+		G_CALLBACK (cb_entry_key_press), G_OBJECT (ie), G_CONNECT_AFTER|G_CONNECT_SWAPPED);
+	g_signal_connect_object (G_OBJECT (ie->entry),
 		"notify::cursor-position",
-		G_CALLBACK (entry_cursor_event), G_OBJECT (ie), G_CONNECT_AFTER|G_CONNECT_SWAPPED);
-
-	ie_scan_for_range (ie);
+		G_CALLBACK (cb_entry_cursor_event), G_OBJECT (ie), G_CONNECT_AFTER|G_CONNECT_SWAPPED);
 
 	/* set the font and the upper left corner if this is the first pass */
 	if (ie->gfont == NULL) {
@@ -569,7 +492,7 @@ item_edit_set_property (GObject *gobject, guint param_id,
 			sheet_style_get (sheet, ie->pos.col, ie->pos.row));
 		ie->gfont = gnm_style_get_font (ie->style,
 			sheet->context, sheet->last_zoom_factor_used);
-		style_font_ref (ie->gfont);
+		gnm_font_ref (ie->gfont);
 
 		if (gnm_style_get_align_h (ie->style) == HALIGN_GENERAL)
 			gnm_style_set_align_h (ie->style, HALIGN_LEFT);
@@ -602,9 +525,6 @@ item_edit_set_property (GObject *gobject, guint param_id,
 	foo_canvas_item_request_update (item);
 }
 
-/*
- * ItemEdit class initialization
- */
 static void
 item_edit_class_init (GObjectClass *gobject_class)
 {
@@ -637,18 +557,3 @@ item_edit_class_init (GObjectClass *gobject_class)
 GSF_CLASS (ItemEdit, item_edit,
 	   item_edit_class_init, item_edit_init,
 	   FOO_TYPE_CANVAS_ITEM);
-
-void
-item_edit_disable_highlight (ItemEdit *ie)
-{
-	g_return_if_fail (ITEM_EDIT (ie) != NULL);
-	ie_destroy_feedback_range (ie);
-	ie->feedback_disabled = TRUE;
-}
-
-void
-item_edit_enable_highlight (ItemEdit *ie)
-{
-	g_return_if_fail (ITEM_EDIT (ie) != NULL);
-	ie->feedback_disabled = FALSE;
-}
