@@ -301,10 +301,10 @@ xml_read_selection_info (XmlParseContext *ctxt, xmlNodePtr tree)
  */
 static char const *const StyleSideNames[6] =
 {
- 	"Top",
- 	"Bottom",
- 	"Left",
- 	"Right",
+	"Top",
+	"Bottom",
+	"Left",
+	"Right",
 	"Diagonal",
 	"Rev-Diagonal"
 };
@@ -321,7 +321,7 @@ xml_read_style_border (XmlParseContext *ctxt, xmlNodePtr tree, GnmStyle *style)
 	}
 
 	for (i = MSTYLE_BORDER_TOP; i <= MSTYLE_BORDER_DIAGONAL; i++) {
- 		if ((side = e_xml_get_child_by_name (tree,
+		if ((side = e_xml_get_child_by_name (tree,
 					      CC2XML (StyleSideNames [i - MSTYLE_BORDER_TOP]))) != NULL) {
 			int		 t;
 			GnmColor      *color = NULL;
@@ -332,7 +332,7 @@ xml_read_style_border (XmlParseContext *ctxt, xmlNodePtr tree, GnmStyle *style)
 			border = gnm_style_border_fetch ((GnmStyleBorderType)t, color,
 						     gnm_style_border_get_orientation (i));
 			gnm_style_set_border (style, i, border);
- 		}
+		}
 	}
 }
 
@@ -507,7 +507,7 @@ xml_read_print_margins (XmlParseContext *ctxt, xmlNodePtr tree)
 	double right = -1.;
 	double edge_to_above_footer = -1.;
 	double edge_to_below_header = -1.;
-	
+
 	g_return_if_fail (ctxt != NULL);
 	g_return_if_fail (tree != NULL);
 	g_return_if_fail (IS_SHEET (ctxt->sheet));
@@ -540,7 +540,7 @@ xml_read_print_margins (XmlParseContext *ctxt, xmlNodePtr tree)
 		print_info_set_edge_to_below_header (pi, edge_to_below_header);
 	if (!(edge_to_above_footer < 0))
 		print_info_set_edge_to_above_footer (pi, edge_to_above_footer);
-	
+
 }
 
 static void
@@ -570,6 +570,34 @@ xml_read_print_repeat_range (XmlParseContext *ctxt, xmlNodePtr tree,
 	}
 }
 
+static void
+xml_read_breaks (XmlParseContext *ctxt, xmlNodePtr tree, gboolean is_vert)
+{
+	GnmPageBreaks *page_breaks;
+	int pos, count = 0;
+	xmlChar *type_str;
+	GnmPageBreakType  type;
+
+	xml_node_get_int (tree, "count", &count);
+	page_breaks = gnm_page_breaks_new (count, is_vert);
+
+	for (tree = tree->xmlChildrenNode; tree != NULL ; tree = tree->next)
+		if (!xmlIsBlankNode (tree) &&
+		    0 == strcmp (tree->name, "break") &&
+		    xml_node_get_int (tree, "pos", &pos) &&
+		    pos >= 0) {
+			if (NULL != (type_str = xml_node_get_cstr  (tree, "type")))
+				type = gnm_page_break_type_from_str (CXML2C (type_str));
+			else
+				type = GNM_PAGE_BREAK_AUTO;
+
+			/* drops invalid positions */
+			gnm_page_breaks_append_break (page_breaks, pos, type);
+		}
+
+	print_info_set_breaks (ctxt->sheet->print_info, page_breaks);
+}
+
 static void
 xml_read_print_info (XmlParseContext *ctxt, xmlNodePtr tree)
 {
@@ -647,6 +675,11 @@ xml_read_print_info (XmlParseContext *ctxt, xmlNodePtr tree)
 		xml_node_get_int  (child, "value",  &b);
 		pi->print_titles          = (b == 1);
 	}
+	if ((child = e_xml_get_child_by_name (tree, CC2XML ("do_not_print")))) {
+		xml_node_get_int  (child, "value",    &b);
+		pi->do_not_print  = (b == 1);
+	}
+
 
 	xml_read_print_repeat_range (ctxt, tree, "repeat_top",
 				     &pi->repeat_top);
@@ -680,6 +713,11 @@ xml_read_print_info (XmlParseContext *ctxt, xmlNodePtr tree)
 		print_info_set_paper (pi, paper);
 		xmlFree (paper);
 	}
+
+	if ((child = e_xml_get_child_by_name (tree, CC2XML ("vPageBreaks"))))
+		xml_read_breaks (ctxt, child, TRUE);
+	if ((child = e_xml_get_child_by_name (tree, CC2XML ("hPageBreaks"))))
+		xml_read_breaks (ctxt, child, FALSE);
 }
 
 static char const *
@@ -1466,7 +1504,7 @@ xml_read_solver (XmlParseContext *ctxt, xmlNodePtr tree)
 
 	if (xml_node_get_int (tree, "TargetCol", &col) && col >= 0 &&
 	    xml_node_get_int (tree, "TargetRow", &row) && row >= 0)
-	        param->target_cell = sheet_cell_fetch (sheet, col, row);
+		param->target_cell = sheet_cell_fetch (sheet, col, row);
 
 	if (xml_node_get_int (tree, "ProblemType", &ptype))
 		param->problem_type = (SolverProblemType)ptype;
@@ -1516,7 +1554,7 @@ xml_read_solver (XmlParseContext *ctxt, xmlNodePtr tree)
 				c->type = SolverLE;
 				break;
 			}
-#ifdef ENABLE_SOLVER
+#ifdef GNM_ENABLE_SOLVER
 			c->str = write_constraint_str (c->lhs.col, c->lhs.row,
 						       c->rhs.col, c->rhs.row,
 						       c->type, c->cols, c->rows);
@@ -1565,24 +1603,24 @@ xml_read_scenarios (XmlParseContext *ctxt, xmlNodePtr tree)
 		s = g_new0 (scenario_t, 1);
 
 		/* Scenario: name. */
-	        str = xml_node_get_cstr (child, "Name");
+		str = xml_node_get_cstr (child, "Name");
 		s->name = g_strdup ((const gchar *)str);
 		xmlFree (str);
 
 		/* Scenario: comment. */
-	        str = xml_node_get_cstr (child, "Comment");
+		str = xml_node_get_cstr (child, "Comment");
 		s->comment = g_strdup ((const gchar *)str);
 		xmlFree (str);
 
 		/* Scenario: changing cells in a string form. */
-	        str = xml_node_get_cstr (child, "CellsStr");
+		str = xml_node_get_cstr (child, "CellsStr");
 		s->cell_sel_str = g_strdup ((const gchar *)str);
 		range = value_new_cellrange_str (sheet, str);
 		if (range) {
-		        GnmValueRange *vrange = (GnmValueRange *) range;
+			GnmValueRange *vrange = (GnmValueRange *) range;
 
-		        s->range.start.col = vrange->cell.a.col;
-		        s->range.start.row = vrange->cell.a.row;
+			s->range.start.col = vrange->cell.a.col;
+			s->range.start.row = vrange->cell.a.row;
 			s->range.end.col   = vrange->cell.b.col;
 			s->range.end.row   = vrange->cell.b.row;
 			value_release (range);
@@ -1594,7 +1632,7 @@ xml_read_scenarios (XmlParseContext *ctxt, xmlNodePtr tree)
 		cols = s->range.end.col - s->range.start.col + 1;
 		s->changing_cells = g_new (GnmValue *, rows * cols);
 		for (i = 0; i < cols * rows; i++) {
-		        GString *name;
+			GString *name;
 
 			name = g_string_new (NULL);
 			g_string_append_printf (name, "V%d", i);
@@ -1671,8 +1709,14 @@ xml_read_sheet_object (XmlParseContext const *ctxt, xmlNodePtr tree)
 	tmp = (char *) xmlGetProp (tree, (xmlChar *)"ObjectBound");
 	if (tmp != NULL) {
 		GnmRange r;
-		if (range_parse (&r, tmp))
+		if (range_parse (&r, tmp)) {
+			/* Patch problems introduced in some 1.7.x versions that stored
+			 * comments in merged cells with the full rectangle of the merged cell
+			 * rather than just the top left corner */
+			if (G_OBJECT_TYPE (so) == CELL_COMMENT_TYPE)
+				r.end = r.start;
 			so->anchor.cell_bound = r;
+		}
 		xmlFree (tmp);
 	}
 
@@ -1684,8 +1728,8 @@ xml_read_sheet_object (XmlParseContext const *ctxt, xmlNodePtr tree)
 		xmlFree (tmp);
 	}
 
-	/* DEPRECATED : There was once an 'AnchorType' but it is now ignored */
 #if 0
+	/* Deprecated in 1.7.7 */
 	tmp = (char *) xmlGetProp (tree, (xmlChar *)"ObjectAnchorType");
 	if (tmp != NULL) {
 		int i[4], count;
@@ -1867,6 +1911,7 @@ xml_sheet_read (XmlParseContext *ctxt, xmlNodePtr tree)
 	gboolean tmp;
 	xmlChar *val;
 	int tmpi;
+	GnmColor *c;
 
 	if (strcmp (tree->name, "Sheet")){
 		g_printerr ("xml_sheet_read: invalid element type %s, 'Sheet' expected\n",
@@ -1923,6 +1968,8 @@ xml_sheet_read (XmlParseContext *ctxt, xmlNodePtr tree)
 		g_object_set (sheet, "visibility", tmpi, NULL);
 	sheet->tab_color = xml_node_get_color (tree, "TabColor");
 	sheet->tab_text_color = xml_node_get_color (tree, "TabTextColor");
+	if (NULL != (c = xml_node_get_color (tree, "GridColor")))
+		sheet_style_set_auto_pattern_color (sheet, c);
 
 	xml_node_get_double (e_xml_get_child_by_name (tree, CC2XML ("Zoom")), NULL,
 			     &zoom_factor);
@@ -2091,8 +2138,8 @@ GnmCellRegion *
 xml_cellregion_read (WorkbookControl *wbc, Sheet *sheet, const char *buffer, int length)
 {
 	XmlParseContext *ctxt;
-	xmlNode	        *l, *clipboard;
-	xmlDoc	        *doc;
+	xmlNode		*l, *clipboard;
+	xmlDoc		*doc;
 	GnmCellRegion   *cr = NULL;
 	GnmLocale       *locale;
 	int dummy;
@@ -2336,7 +2383,7 @@ xml_workbook_read (IOContext *context,
 	io_progress_message (context, _("Processing file..."));
 	io_progress_range_push (context, 0.5, 1.0);
 	count_io_progress_set (context, xml_read_workbook_n_elements (child),
-	                       N_ELEMENTS_BETWEEN_UPDATES);
+			       N_ELEMENTS_BETWEEN_UPDATES);
 	ctxt->io_context = context;
 
 	/*
@@ -2372,7 +2419,7 @@ xml_workbook_read (IOContext *context,
 	if (child) {
 		int sheet_index = 0;
 		if (xml_node_get_int (child, "SelectedTab", &sheet_index)) {
-			Sheet *sheet = workbook_sheet_by_index (ctxt->wb, 
+			Sheet *sheet = workbook_sheet_by_index (ctxt->wb,
 								sheet_index);
 			if (sheet)
 				wb_view_sheet_focus (ctxt->wb_view, sheet);
@@ -2382,7 +2429,7 @@ xml_workbook_read (IOContext *context,
 	child = e_xml_get_child_by_name (tree, CC2XML ("Calculation"));
 	if (child != NULL) {
 		gboolean b;
-		int 	 i;
+		int	 i;
 		double	 d;
 
 		if (xml_node_get_bool (child, "ManualRecalc", &b))
@@ -2566,7 +2613,7 @@ xml_probe (GOFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
 		name = gsf_extension_pointer (name);
 
 		return (name != NULL &&
-		        (g_ascii_strcasecmp (name, "gnumeric") == 0 ||
+			(g_ascii_strcasecmp (name, "gnumeric") == 0 ||
 			 g_ascii_strcasecmp (name, "xml") == 0));
 	}
 
